@@ -1,6 +1,7 @@
 import random
 
 from alira.modules import module
+from alira.instance import Instance
 
 PIPELINE_MODULE_NAME = "selection"
 
@@ -37,7 +38,7 @@ class Selection(module.Module):
 
         self.percentage = percentage
 
-    def run(self, instance):
+    def run(self, instance: Instance, **kwargs):
         """
         Processes the supplied instances and set a boolean value indicating
         whether it should be selected for human review.
